# -*- coding: cp1252 -*-
#
# Tlmtrie de donnes de l'IMU intgre  la Carambola-Box.
# Ce programme est destin  fonctionner avec la Carambola-Box,
# disponible  l'adresse suivante:
# http://boutique.3sigma.fr/30-carambola-box-version-complete.html
#
# Bas sur ComPlotter.py de Ted Burke (11-5-2012)
#
# Auteur: 3Sigma
# Version 1.0 - 14/06/2013

# TelemetrieCarambola est un logiciel libre ; vous pouvez la redistribuer ou
# la modifier suivant les termes de la Licence Gnrale Publique Limite
# GNU telle que publie par la Free Software Foundation ; soit la
# version 3 de la License, soit ( votre gr) toute version ultrieure.
# Ce script est distribu dans l'espoir qu'il sera utile, mais
# SANS AUCUNE GARANTIE : sans mme la garantie implicite de
# COMMERCIALISABILIT ou d'ADQUATION  UN OBJECTIF PARTICULIER. Consultez
# la Licence Gnrale Publique Limite pour plus de dtails.
# Vous devriez avoir reu une copie de la Licence Gnrale Publique Limite
# GNU avec ce scriptque ; si ce n'est pas le cas, crivez  la :
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

# Ce programme ncessite Python 2.7 et les bibliothques suivantes:
# - wxPython (http://www.wxpython.org/download.php) 
# - Numpy (http://sourceforge.net/projects/numpy/files/) 
# - Crypto (https://pypi.python.org/pypi/pycrypto) 
# - Paramiko (https://pypi.python.org/pypi/paramiko/1.10.1) 


import socket
import wx.html
import wx.lib.plot as plot
import numpy
import os
import shutil
import paramiko

helpText1 = """
<p><strong>Bande passante du filtre passe-bas</strong></p>
<p>Cette option permet de dfinir la frquence de coupure du filtre-passe bas sur les 
acclrations et les vitesses de rotation.</p>
<p>Une frquence leve fait apparatre plus de bruit. Une frquence plus basse filtre 
le bruit mais galement les signaux transitoires trs rapides, comme les chocs.</p>
"""

helpText2 = """
<p><strong>Rafraichissement</strong></p>
<p>Cette option permet de r&eacute;gler la fr&eacute;quence de rafraichissement des 
courbes pour que celles-ci s'affichent en temps-r&eacute;el sur des ordinateurs peu ou 
moyennement performants.</p>
<p>Commencez par choisir une fr&eacute;quence &eacute;lev&eacute;e. Si les courbes 
s'affichent en temps-r&eacute;el (sans d&eacute;calage par rapport aux consignes que 
vous pouvez donner), c'est parfait. Sinon, s&eacute;lectionnez dans la liste 
d&eacute;roulante la fr&eacute;quence (moyenne, lente ou tr&egrave;s lente) qui convient 
&agrave; votre ordinateur, au prix d'un affichage plus saccad&eacute;. </p>
"""


class HtmlWindow1(wx.html.HtmlWindow):
	def __init__(self, parent, id, size=(600, 400)):
		wx.html.HtmlWindow.__init__(self, parent, id, size=size)
		if "gtk2" in wx.PlatformInfo:
			self.SetStandardFonts()

	def OnLinkClicked(self, link):
		wx.LaunchDefaultBrowser(link.GetHref())


class HtmlWindow2(wx.html.HtmlWindow):
	def __init__(self, parent, id, size=(600, 400)):
		wx.html.HtmlWindow.__init__(self, parent, id, size=size)
		if "gtk2" in wx.PlatformInfo:
			self.SetStandardFonts()

	def OnLinkClicked(self, link):
		wx.LaunchDefaultBrowser(link.GetHref())


class HelpBox1(wx.Dialog):
	def __init__(self):
		wx.Dialog.__init__(self, None, -1, "Aide",
            style = wx.DEFAULT_DIALOG_STYLE | wx.THICK_FRAME | wx.RESIZE_BORDER | 
                wx.TAB_TRAVERSAL)
		hwin = HtmlWindow1(self, -1, size=(400, 200))
		hwin.SetPage(helpText1)
		btn = hwin.FindWindowById(wx.ID_OK)
		irep = hwin.GetInternalRepresentation()
		hwin.SetSize((irep.GetWidth() + 25, irep.GetHeight() + 10))
		self.SetClientSize(hwin.GetSize())
		self.CentreOnParent(wx.BOTH)
		self.SetFocus()


class HelpBox2(wx.Dialog):
	def __init__(self):
		wx.Dialog.__init__(self, None, -1, "Aide",
            style = wx.DEFAULT_DIALOG_STYLE | wx.THICK_FRAME | wx.RESIZE_BORDER | 
                wx.TAB_TRAVERSAL)
		hwin = HtmlWindow2(self, -1, size=(400, 200))
		hwin.SetPage(helpText2)
		btn = hwin.FindWindowById(wx.ID_OK)
		irep = hwin.GetInternalRepresentation()
		hwin.SetSize((irep.GetWidth() + 25, irep.GetHeight() + 10))
		self.SetClientSize(hwin.GetSize())
		self.CentreOnParent(wx.BOTH)
		self.SetFocus()


class DataLoggerWindow(wx.Frame):
	def __init__(self):
		wx.Frame.__init__(self, None, -1, "Carambola-Box - Tlmtrie IMU", (0, 0), (1024, 740))

		self.SetBackgroundColour('#ece9d8')

		# Initialisations
		self.isLogging = False

		self.count = 0

		fb = open("Telemetrie.ini", "r")
		myip = (fb.readline()).strip()
		if myip == '':
			myip = '192.168.0.199'

		myport = (fb.readline()).strip()
		if myport == '':
			myport = '5000'

		mybp = (fb.readline()).strip()
		if mybp == '':
			mybp = '260 Hz'

		mylogin = (fb.readline()).strip()
		if mylogin == '':
			mylogin = 'root'

		mypass = (fb.readline()).strip()
		if mypass == '':
			mypass = 'admin'

		myraf = (fb.readline()).strip()
		if myraf == '':
			myraf = 'Lent'

		self.M = 8

		fb.close()

		if myraf == 'Rapide':
			self.facteurDecim = 0
		elif myraf == 'Moyen':
			self.facteurDecim = 1
		elif myraf == 'Lent':
			self.facteurDecim = 4
		elif myraf == 'Minimum':
			self.facteurDecim = 9
		else:
			self.facteurDecim = 1

		# Acquisition  20 Hz
		self.Facq = int(20)
		self.Tacq = 1 / self.Facq
		self.N = 10 * self.Facq + 1
		self.n = [x * self.Tacq for x in range(self.N)]

		self.x = []
		self.data = []
		self.line0 = []
		self.line1 = []
		self.line2 = []
		self.line3 = []
		self.line4 = []
		self.line5 = []
		for m in range(self.M):
			self.x.append(0. * numpy.ones(self.N, numpy.int))
			self.data.append(0. * numpy.ones(self.N, numpy.int))

		self.plotter0 = plot.PlotCanvas(self)
		self.plotter0.SetInitialSize(size=(320, 240))
		self.plotter0.SetFontSizeTitle(10)
		self.plotter0.SetPosition([0, 0])
		self.plotter0.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line0 = plot.PolyLine(data, colour='red', width=1)
		gc0 = plot.PlotGraphics([line0], 'Ax (m/s^2)', 'Temps (s)', '')
		self.plotter0.Draw(gc0, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter0.SetEnableZoom(False)
		self.plotter0.SetGridColour('grey')
		self.plotter0.SetEnableGrid(True)
		self.plotter0.SetEnableLegend(False)

		self.plotter1 = plot.PlotCanvas(self)
		self.plotter1.SetInitialSize(size=(320, 240))
		self.plotter1.SetFontSizeTitle(10)
		self.plotter1.SetPosition([340, 0])
		self.plotter1.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line1 = plot.PolyLine(data, colour='blue', width=1)
		gc1 = plot.PlotGraphics([line1], 'Ay (m/s^2)', 'Temps (s)', '')
		self.plotter1.Draw(gc1, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter1.SetEnableZoom(False)
		self.plotter1.SetGridColour('grey')
		self.plotter1.SetEnableGrid(True)
		self.plotter1.SetEnableLegend(False)

		self.plotter2 = plot.PlotCanvas(self)
		self.plotter2.SetInitialSize(size=(320, 240))
		self.plotter2.SetFontSizeTitle(10)
		self.plotter2.SetPosition([680, 0])
		self.plotter2.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line2 = plot.PolyLine(data, colour='green', width=1)
		gc2 = plot.PlotGraphics([line2], 'Az (m/s^2)', 'Temps (s)', '')
		self.plotter2.Draw(gc2, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter2.SetEnableZoom(False)
		self.plotter2.SetGridColour('grey')
		self.plotter2.SetEnableGrid(True)
		self.plotter2.SetEnableLegend(False)

		self.plotter3 = plot.PlotCanvas(self)
		self.plotter3.SetInitialSize(size=(320, 240))
		self.plotter3.SetFontSizeTitle(10)
		self.plotter3.SetPosition([0, 250])
		self.plotter3.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line3 = plot.PolyLine(data, colour='magenta', width=1)
		gc3 = plot.PlotGraphics([line3], 'Wx (rad/s)', 'Temps (s)', '')
		self.plotter3.Draw(gc3, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter3.SetEnableZoom(False)
		self.plotter3.SetGridColour('grey')
		self.plotter3.SetEnableGrid(True)
		self.plotter3.SetEnableLegend(False)

		self.plotter4 = plot.PlotCanvas(self)
		self.plotter4.SetInitialSize(size=(320, 240))
		self.plotter4.SetFontSizeTitle(10)
		self.plotter4.SetPosition([340, 250])
		self.plotter4.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line4 = plot.PolyLine(data, colour='orange', width=1)
		gc4 = plot.PlotGraphics([line4], 'Wy (rad/s)', 'Temps (s)', '')
		self.plotter4.Draw(gc4, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter4.SetEnableZoom(False)
		self.plotter4.SetGridColour('grey')
		self.plotter4.SetEnableGrid(True)
		self.plotter4.SetEnableLegend(False)

		self.plotter5 = plot.PlotCanvas(self)
		self.plotter5.SetInitialSize(size=(320, 240))
		self.plotter5.SetFontSizeTitle(10)
		self.plotter5.SetPosition([680, 250])
		self.plotter5.SetBackgroundColour('#ece9d8')
		data = [(0, 0)]
		line5 = plot.PolyLine(data, colour='cyan', width=1)
		gc5 = plot.PlotGraphics([line5], 'Wz (rad/s)', 'Temps (s)', '')
		self.plotter5.Draw(gc5, xAxis=(0, 10), yAxis=(-1, 1))
		self.plotter5.SetEnableZoom(False)
		self.plotter5.SetGridColour('grey')
		self.plotter5.SetEnableGrid(True)
		self.plotter5.SetEnableLegend(False)

		# Zone de texte pour le log
		self.log_text = wx.TextCtrl(
			self, -1, pos=(450, 520), size=(355, 100),
			style=wx.TE_MULTILINE | wx.TE_RICH)
		self.log_text.SetFont(
			wx.Font(10, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))

		# Timer de lecture des donnes
		self.timer = wx.Timer(self)
		self.Bind(wx.EVT_TIMER, self.GetSample, self.timer)

		# Adresse IP
		wx.StaticText(self, -1, "Adresse IP:", (30, 505), style=wx.ALIGN_LEFT)
		self.text_IP = wx.TextCtrl(self, -1, "10", pos=(25, 525), size=(100, 20))
		self.text_IP.SetValue(myip)

		# Port
		wx.StaticText(self, -1, "Port:", (150, 505), style=wx.ALIGN_LEFT)
		self.text_Port = wx.TextCtrl(self, -1, "10", pos=(145, 525), size=(100, 20))
		self.text_Port.SetValue(myport)

		# Bande passante
		wx.StaticText(self, -1, "Bande passante filtre:", (270, 505), style=wx.ALIGN_LEFT)
		self.bandespassantes = ['260 Hz', '184 Hz', '94 Hz', '44 Hz', '21 Hz', '10 Hz', '5 Hz']
		self.cbbp = wx.ComboBox(self, -1, pos=(265, 525), size=(80, -1), choices=self.bandespassantes, style=wx.CB_READONLY)
		self.cbbp.SetValue(mybp)

		# Cration du bouton d'aide pour la bande passante
		self.help_button = wx.Button(
			self, label="?", pos=(352, 525), size=(20, 20))
		self.help_button.SetFont(
			wx.Font(8, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.help_button.Bind(
			wx.EVT_BUTTON, self.onHelpButton1)

		# Login
		wx.StaticText(self, -1, "Login:", (30, 565), style=wx.ALIGN_LEFT)
		self.text_Login = wx.TextCtrl(self, -1, "10", pos=(25, 585), size=(100, 20))
		self.text_Login.SetValue(mylogin)

		# Mot de passe
		wx.StaticText(self, -1, "Mot de passe:", (150, 565), style=wx.ALIGN_LEFT)
		self.text_Pass = wx.TextCtrl(self, -1, "10", pos=(145, 585), size=(100, 20), style=wx.TE_PASSWORD)
		self.text_Pass.SetValue(mypass)

		# Frquence de rafraichissement
		wx.StaticText(self, -1, "Rafraichissement:", (270, 565), style=wx.ALIGN_LEFT)
		self.raf = wx.ComboBox(self, -1, pos=(265, 585), size=(67, -1), choices=['Rapide', 'Moyen', 'Lent', 'Minimum'], style=wx.CB_READONLY)
		self.raf.SetValue(myraf)
		self.raf.Bind(wx.EVT_COMBOBOX, self.onRafCombo)

		# Cration du bouton d'aide pour la frquence de rafraichissement
		self.help_button = wx.Button(
			self, label="?", pos=(340, 585), size=(20, 20))
		self.help_button.SetFont(
			wx.Font(8, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.help_button.Bind(
			wx.EVT_BUTTON, self.onHelpButton2)

		# Bouton de calibration
		self.calibration_button = wx.Button(
			self, label="Calibration", pos=(25, 625), size=(65, 20))
		self.calibration_button.SetFont(
			wx.Font(8, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.calibration_button.Bind(
			wx.EVT_BUTTON, self.onCalibrationButton)

		# Bouton d'acquisition
		self.start_stop_button = wx.Button(
			self, label="Acquisition", pos=(145, 625), size=(65, 20))
		self.start_stop_button.SetFont(
			wx.Font(8, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.start_stop_button.Bind(
			wx.EVT_BUTTON, self.onStartStopButton)

		# Bouton d'enregistrement
		self.save_button = wx.Button(
			self, label="Enregistrer", pos=(450, 625), size=(75, 20))
		self.save_button.SetFont(
			wx.Font(8, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.save_button.Disable()
		self.save_button.Bind(
			wx.EVT_BUTTON, self.onSaveButton)

		# Temprature
		wx.StaticText(self, -1, "Temprature dans le boitier:", (850, 515), style=wx.ALIGN_LEFT)
		self.text_Temp = wx.StaticText(self, -1, "", (850, 535), style=wx.ALIGN_LEFT)
		self.text_Temp.SetLabel("--.-" + " C")
		self.text_Temp.SetFont(
			wx.Font(24, wx.DEFAULT, wx.NORMAL, wx.NORMAL, False))
		self.text_Temp.SetForegroundColour('maroon')


	def GetSample(self, event=None):

		# Rception des donnes sur le rseau
		sample_string = self.linesplit(self.s)

		for splstr in sample_string:
			# Ajout des donnes dans la zone de log
			self.log_text.AppendText(splstr)

			# Extraction des donnes de chaque voie du capteur
			sample_string = splstr[0:-1]
			sample_values = sample_string.split(",")

			if len(sample_values) == self.M:

				# Mme si le nombre de champs est correct, la dernire valeur
				# est peut-tre nulle
				try:
					value = float(sample_values[self.M - 1])
				except:
					print sample_string
					break

				# Rangement des mesures dans un tableau
				for m in range(self.M):
					value = float(sample_values[m])
					self.x[m][0:self.N - 1] = self.x[m][1:]
					self.x[m][self.N - 1] = value

				for m in range(1, self.M):
					self.data[m] = [(self.x[0][i], self.x[m][i]) for i in range(self.N - 1)]

				# Dtermination des min et max sur chaque voie
				maxy0 = max(self.x[1])
				miny0 = min(self.x[1])
				maxy1 = max(self.x[2])
				miny1 = min(self.x[2])
				maxy2 = max(self.x[3])
				miny2 = min(self.x[3])
				maxy3 = max(self.x[4])
				miny3 = min(self.x[4])
				maxy4 = max(self.x[5])
				miny4 = min(self.x[5])
				maxy5 = max(self.x[6])
				miny5 = min(self.x[6])

				# Trac des courbes
				if self.count >= self.facteurDecim:
					self.text_Temp.SetLabel(str(self.data[7][-1][-1]) + " C")

					self.count = 0
					line0 = plot.PolyLine(self.data[1], colour='red', width=2)
					line1 = plot.PolyLine(self.data[2], colour='blue', width=2)
					line2 = plot.PolyLine(self.data[3], colour='green', width=2)
					line3 = plot.PolyLine(self.data[4], colour='magenta', width=2)
					line4 = plot.PolyLine(self.data[5], colour='orange', width=2)
					line5 = plot.PolyLine(self.data[6], colour='cyan', width=2)

					gc0 = plot.PlotGraphics([line0], 'Ax (m/s^2)', 'Temps (s)', '')
					gc1 = plot.PlotGraphics([line1], 'Ay (m/s^2)', 'Temps (s)', '')
					gc2 = plot.PlotGraphics([line2], 'Az (m/s^2)', 'Temps (s)', '')
					gc3 = plot.PlotGraphics([line3], 'Wx (rad/s)', 'Temps (s)', '')
					gc4 = plot.PlotGraphics([line4], 'Wy (rad/s)', 'Temps (s)', '')
					gc5 = plot.PlotGraphics([line5], 'Wz (rad/s)', 'Temps (s)', '')
					if self.x[0][-1] < self.N * self.Tacq:
						self.plotter0.Draw(gc0, xAxis=(0, 10), yAxis=(miny0 - 1., maxy0 + 1.))
						self.plotter1.Draw(gc1, xAxis=(0, 10), yAxis=(miny1 - 1., maxy1 + 1.))
						self.plotter2.Draw(gc2, xAxis=(0, 10), yAxis=(miny2 - 1., maxy2 + 1.))
						self.plotter3.Draw(gc3, xAxis=(0, 10), yAxis=(miny3 - 1., maxy3 + 1.))
						self.plotter4.Draw(gc4, xAxis=(0, 10), yAxis=(miny4 - 1., maxy4 + 1.))
						self.plotter5.Draw(gc5, xAxis=(0, 10), yAxis=(miny5 - 1., maxy5 + 1.))
					else:
						self.plotter0.Draw(gc0, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny0 - 1., maxy0 + 1.))
						self.plotter1.Draw(gc1, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny1 - 1., maxy1 + 1.))
						self.plotter2.Draw(gc2, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny2 - 1., maxy2 + 1.))
						self.plotter3.Draw(gc3, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny3 - 1., maxy3 + 1.))
						self.plotter4.Draw(gc4, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny4 - 1., maxy4 + 1.))
						self.plotter5.Draw(gc5, xAxis=(max(0, self.x[0][-1]-10), max(10, self.x[0][-1])), yAxis=(miny5 - 1., maxy5 + 1.))
				else:
					self.count = self.count + 1


	def linesplit(self, socket):
		done = False
		if self.isLogging:
			try:
				buff = socket.recv(1024)
				erreur_buff = False
			except:
				erreur_buff = True
				done = True
				pass
		else:
			done = True
		while not done:
			if "\n" in buff:
				(line, buff) = buff.split("\n", 1)
				yield line + "\n"
			else:
				if self.isLogging:
					try:
						more = socket.recv(1024)
					except:
						break
					if not more:
						done = True
					else:
						buff = buff + more
				else:
					done = True
		if not erreur_buff:
			if buff:
				yield buff


	def onStartStopButton(self, event):
		if not self.isLogging:
			self.Facq = int(20)
			self.Tacq = 1 / self.Facq
			self.N = 10 * self.Facq + 1
			self.n = [x * self.Tacq for x in range(self.N)]

			self.M = 8

			self.x = []
			self.data = []
			self.line = []
			for m in range(self.M):
				self.x.append(0. * numpy.ones(self.N, numpy.int))
				self.data.append(0. * numpy.ones(self.N, numpy.int))

			# Rcupration des infos de connexion
			HOST = self.text_IP.GetValue()
			PORT = self.text_Port.GetValue()
			LOGIN = self.text_Login.GetValue()
			PASSWORD = self.text_Pass.GetValue()

			try:
				self.plotter0.SetEnableZoom(False)
				self.plotter1.SetEnableZoom(False)
				self.plotter2.SetEnableZoom(False)
				self.plotter3.SetEnableZoom(False)
				self.plotter4.SetEnableZoom(False)
				self.plotter5.SetEnableZoom(False)
				self.save_button.Disable()
				self.text_IP.Disable()
				self.text_Port.Disable()
				self.cbbp.Disable()
				self.text_Login.Disable()
				self.text_Pass.Disable()
				self.calibration_button.Disable()
				self.log_text.SetValue('')
				self.log_text.AppendText(
					'Ouverture de l\'hote ' + HOST + ' sur le port ' + PORT + '...\n')
				with open("Telemetrie.ini", "w") as myfile:
					myfile.write(HOST)
					myfile.write('\n' + PORT)
					myfile.write('\n' + self.cbbp.GetValue())
					myfile.write('\n' + LOGIN)
					myfile.write('\n' + PASSWORD)
					myfile.write('\n' + self.raf.GetValue())

				# Connexion en SSH
				ssh = paramiko.SSHClient()
				ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
				ssh.connect(HOST, username=LOGIN, password=PASSWORD)
				# Excution distante du script d'envoi des donnes sur le rseau
				ssh.exec_command("python /root/IMU/Python/TelemetrieIMU.py " + str(self.bandespassantes.index(self.cbbp.GetValue())))
				ssh.close()

				# Connexion au flux de donnes envoyes sur le rseau
				self.s = socket.create_connection((HOST, int(PORT)))
				self.log_text.AppendText(
					'Connect.\n')

				self.s.setblocking(0)
				self.isLogging = True
				self.timer.Start(200)
				self.start_stop_button.SetLabel("Stop")

			except socket.error as msg:
				# Si problme de connexion...
				self.log_text.AppendText(
					'Echec  l\'ouverture de l\'hote ' + HOST + ' sur le port ' + str(PORT) + '\n')
				self.log_text.AppendText(
					str(msg) + '\n\n')
				self.log_text.AppendText(
					'Veuillez essayer de nouveau ou vrifiez vos paramtres de connexion.\n')
				self.save_button.Enable()
				self.text_IP.Enable()
				self.text_Port.Enable()
				self.cbbp.Enable()
				self.text_Login.Enable()
				self.text_Pass.Enable()
				self.calibration_button.Enable()
				pass

		else:
			self.timer.Stop()
			self.isLogging = False
			self.s.close()
			self.start_stop_button.SetLabel("Acquisition")
			self.plotter0.SetEnableZoom(True)
			self.plotter1.SetEnableZoom(True)
			self.plotter2.SetEnableZoom(True)
			self.plotter3.SetEnableZoom(True)
			self.plotter4.SetEnableZoom(True)
			self.plotter5.SetEnableZoom(True)
			fb2 = open("output.txt", "w")
			self.str_out = self.log_text.GetValue()
			fb2.write(self.str_out[1 + len(self.str_out.split("\n")[0]) + len(self.str_out.split("\n")[1]):])
			fb2.close()
			self.save_button.Enable()
			self.text_IP.Enable()
			self.text_Port.Enable()
			self.cbbp.Enable()
			self.text_Login.Enable()
			self.text_Pass.Enable()
			self.calibration_button.Enable()


	def onRafCombo(self, event):
		if self.raf.GetValue() == 'Rapide':
			self.facteurDecim = 0
		elif self.raf.GetValue() == 'Moyen':
			self.facteurDecim = 1
		elif self.raf.GetValue() == 'Lent':
			self.facteurDecim = 4
		elif self.raf.GetValue() == 'Minimum':
			self.facteurDecim = 9
		else:
			self.facteurDecim = 1


	def onCalibrationButton(self, event):
			self.log_text.AppendText("Lancement de la procdure de calibration...\n")
			# Rcupration des infos de connexion
			HOST = self.text_IP.GetValue()
			LOGIN = self.text_Login.GetValue()
			PASSWORD = self.text_Pass.GetValue()
			
			# Connexion en SSH
			ssh = paramiko.SSHClient()
			ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
			ssh.connect(HOST, username=LOGIN, password=PASSWORD)
			# Excution distante du script d'envoi des donnes sur le rseau
			stdin, stdout, stderr = ssh.exec_command("python /root/IMU/Python/CalibrationIMU.py")
			self.log_text.AppendText(stdout.read())
			ssh.close()


	def onHelpButton1(self, event):
		#wx.MessageBox("Aide Bande passante", caption='Aide')
		dlg = HelpBox1()
		dlg.ShowModal()
		dlg.Destroy()


	def onHelpButton2(self, event):
		#wx.MessageBox("Aide Rafraichissement", caption='Aide')
		dlg = HelpBox2()
		dlg.ShowModal()
		dlg.Destroy()


	def onSaveButton(self, event):
		self.fichier_mesures = wx.SaveFileSelector('Mesures', '.csv', default_name='')
		if os.path.isfile(self.fichier_mesures):
			confirmReplace = wx.MessageBox("Ce fichier existe dj.\n"
                        "Voulez-vous l'craser?",
                        "Remplacement de fichier",
                        style=wx.YES_NO|wx.ICON_QUESTION)
			if confirmReplace == wx.YES:
				try:
					shutil.copyfile('output.txt', self.fichier_mesures)
				except IOError:
					wx.MessageBox("L'criture du fichier a rencontr un problme.\nVrifiez si le fichier n'est pas ouvert ou protg en criture", 'Problme', wx.OK | wx.ICON_ERROR)
		else:
			try:
				shutil.copyfile('output.txt', self.fichier_mesures)
			except IOError:
					wx.MessageBox("L'criture du fichier a rencontr un problme.\nVrifiez si le fichier n'est pas ouvert ou protg en criture", 'Problme', wx.OK | wx.ICON_ERROR)


if __name__ == '__main__':
	app = wx.PySimpleApp()
	window = DataLoggerWindow()

	window.Show()
	app.MainLoop()
